@@ -4,7 +4,7 @@ kombu.messaging
 
 Sending and receiving messages.
 
-:copyright: (c) 2009 - 2010 by Ask Solem.
+:copyright: (c) 2009 - 2011 by Ask Solem.
 :license: BSD, see LICENSE for more details.
 
 """
@@ -29,16 +29,17 @@ class Producer(object):
     :keyword auto_declare: Automatically declare the exchange
       at instantiation. Default is :const:`True`.
     :keyword on_return: Callback to call for undeliverable messages,
-        when the `mandatory` or `imediate` arguments to
+        when the `mandatory` or `immediate` arguments to
         :meth:`publish` is used. This callback needs the following
         signature: `(exception, exchange, routing_key, message)`.
+        Note that the producer needs to drain events to use this feature.
 
     """
     #: The connection channel used.
     channel = None
 
     #: Default exchange.
-    exchange = Exchange("")
+    exchange = None
 
     # Default routing key.
     routing_key = ""
@@ -62,6 +63,8 @@ class Producer(object):
             on_return=None):
         self.channel = channel
         self.exchange = exchange or self.exchange
+        if self.exchange is None:
+            self.exchange = Exchange("")
         self.routing_key = routing_key or self.routing_key
         self.serializer = serializer or self.serializer
         self.compression = compression or self.compression
@@ -70,7 +73,8 @@ class Producer(object):
             self.auto_declare = auto_declare
 
         self.exchange = self.exchange(self.channel)
-        self.auto_declare and self.declare()
+        if self.auto_declare:
+            self.declare()
 
         if self.on_return:
             self.channel.events["basic_return"].append(self.on_return)
@@ -161,7 +165,7 @@ class Consumer(object):
     """Message consumer.
 
     :param channel: see :attr:`channel`.
-    :param queues see :attr:`queues`.
+    :param queues: see :attr:`queues`.
     :keyword no_ack: see :attr:`no_ack`.
     :keyword auto_declare: see :attr:`auto_declare`
     :keyword callbacks: see :attr:`callbacks`.
