@@ -1,5 +1,5 @@
 import socket
-import unittest2 as unittest
+from kombu.tests.utils import unittest
 
 from kombu.connection import BrokerConnection
 from kombu.entity import Exchange, Queue
@@ -100,7 +100,7 @@ class test_MemoryTransport(unittest.TestCase):
         self.assertIsNone(self.q2(channel).get())
 
     def test_drain_events(self):
-        self.assertRaises(ValueError, self.c.drain_events, timeout=0.1)
+        self.assertRaises(socket.timeout, self.c.drain_events, timeout=0.1)
 
         c1 = self.c.channel()
         c2 = self.c.channel()
@@ -115,7 +115,7 @@ class test_MemoryTransport(unittest.TestCase):
 
         class Cycle(object):
 
-            def get(self):
+            def get(self, timeout=None):
                 return ("foo", "foo"), c1
 
         self.c.transport.cycle = Cycle()
