@@ -1,8 +1,11 @@
 import pickle
 import sys
-import unittest2 as unittest
+from kombu.tests.utils import unittest
 
-from StringIO import StringIO
+if sys.version_info >= (3, 0):
+    from io import StringIO, BytesIO
+else:
+    from StringIO import StringIO, StringIO as BytesIO
 
 from kombu import utils
 from kombu.utils.functional import wraps
@@ -119,15 +122,6 @@ class test_Misc(unittest.TestCase):
               u"bar": "bar"}
         self.assertTrue(f(**utils.kwdict(kw)))
 
-    def test_repeatlast(self):
-        x = [1, 2, 3, 4]
-        it = utils.repeatlast(x)
-        self.assertEqual(it.next(), 1)
-        self.assertEqual(it.next(), 2)
-        self.assertEqual(it.next(), 3)
-        self.assertEqual(it.next(), 4)
-        self.assertEqual(it.next(), 4)
-
 
 class MyStringIO(StringIO):
 
@@ -135,11 +129,17 @@ class MyStringIO(StringIO):
         pass
 
 
+class MyBytesIO(BytesIO):
+
+    def close(self):
+        pass
+
+
 class test_emergency_dump_state(unittest.TestCase):
 
     @redirect_stdouts
     def test_dump(self, stdout, stderr):
-        fh = MyStringIO()
+        fh = MyBytesIO()
 
         utils.emergency_dump_state({"foo": "bar"}, open_file=lambda n, m: fh)
         self.assertDictEqual(pickle.loads(fh.getvalue()), {"foo": "bar"})
@@ -182,7 +182,7 @@ def insomnia(fun):
     return _inner
 
 
-class test_retry_over_Time(unittest.TestCase):
+class test_retry_over_time(unittest.TestCase):
 
     @insomnia
     def test_simple(self):
@@ -193,15 +193,15 @@ class test_retry_over_Time(unittest.TestCase):
 
         def myfun():
             sleepvals = {0: None,
-                         1: 2,
-                         2: 4,
-                         3: 6,
-                         4: 8,
-                         5: 10,
-                         6: 12,
-                         7: 14,
-                         8: 14,
-                         9: 14}
+                         1: 2.0,
+                         2: 4.0,
+                         3: 6.0,
+                         4: 8.0,
+                         5: 10.0,
+                         6: 12.0,
+                         7: 14.0,
+                         8: 16.0,
+                         9: 16.0}
             self.assertEqual(_tried_to_sleep[0], sleepvals[index[0]])
             if index[0] < 9:
                 raise Predicate()
