@@ -4,7 +4,7 @@ kombu.transport.base
 
 Base transport interface.
 
-:copyright: (c) 2009 - 2010 by Ask Solem.
+:copyright: (c) 2009 - 2011 by Ask Solem.
 :license: BSD, see LICENSE for more details.
 
 """
@@ -64,7 +64,7 @@ class Message(object):
         compression = self.headers.get("compression")
         if compression:
             self.body = decompress(self.body, compression)
-        if postencode:
+        if postencode and isinstance(self.body, unicode):
             self.body = self.body.encode(postencode)
 
     def ack(self):
@@ -163,3 +163,6 @@ class Transport(object):
 
     def drain_events(self, connection, **kwargs):
         raise NotImplementedError("Subclass responsibility")
+
+    def verify_connection(self, connection):
+        return True
