@@ -4,7 +4,7 @@ kombu.transport.pyamqplib
 
 amqplib transport.
 
-:copyright: (c) 2009 - 2010 by Ask Solem.
+:copyright: (c) 2009 - 2011 by Ask Solem.
 :license: BSD, see LICENSE for more details.
 
 """
@@ -171,8 +171,8 @@ class Channel(_Channel):
         return amqp.Message(message_data, priority=priority,
                             content_type=content_type,
                             content_encoding=content_encoding,
-                            properties=properties,
-                            application_headers=headers)
+                            application_headers=headers,
+                            **properties)
 
     def message_to_python(self, raw_message):
         """Convert encoded message body back to a Python value."""
@@ -210,14 +210,19 @@ class Transport(base.Transport):
             raise KeyError("Missing password for AMQP connection.")
         if not conninfo.port:
             conninfo.port = self.default_port
-        return self.Connection(host=conninfo.host,
+        conn = self.Connection(host=conninfo.host,
                                userid=conninfo.userid,
                                password=conninfo.password,
                                virtual_host=conninfo.virtual_host,
                                insist=conninfo.insist,
                                ssl=conninfo.ssl,
                                connect_timeout=conninfo.connect_timeout)
+        conn.client = self.client
+        return conn
 
     def close_connection(self, connection):
         """Close the AMQP broker connection."""
         connection.close()
+
+    def verify_connection(self, connection):
+        return connection.channels is not None
