@@ -352,14 +352,15 @@ class Channel(AbstractChannel):
 
     def basic_cancel(self, consumer_tag):
         """Cancel consumer by consumer tag."""
-        self._consumers.remove(consumer_tag)
-        self._reset_cycle()
-        queue = self._tag_to_queue.pop(consumer_tag, None)
-        try:
-            self._active_queues.remove(queue)
-        except ValueError:
-            pass
-        self.connection._callbacks.pop(queue, None)
+        if consumer_tag in self._consumers:
+            self._consumers.remove(consumer_tag)
+            self._reset_cycle()
+            queue = self._tag_to_queue.pop(consumer_tag, None)
+            try:
+                self._active_queues.remove(queue)
+            except ValueError:
+                pass
+            self.connection._callbacks.pop(queue, None)
 
     def basic_get(self, queue, **kwargs):
         """Get message by direct access (synchronous)."""
@@ -531,6 +532,9 @@ class Transport(base.Transport):
     #: queue/callback map.
     _callbacks = None
 
+    #: Time to sleep between unsuccessful polls.
+    polling_interval = 0.1
+
     def __init__(self, client, **kwargs):
         self.client = client
         self.channels = []
@@ -571,7 +575,7 @@ class Transport(base.Transport):
                 if timeout and time() - time_start >= timeout:
                     raise socket.timeout()
                 loop += 1
-                sleep(0.1)
+                sleep(self.polling_interval)
             else:
                 break
 
