@@ -1,8 +1,5 @@
-import pickle
 import sys
-import tempfile
 
-from pprint import pformat
 from time import sleep
 from uuid import UUID, uuid4 as _uuid4, _uuid_generate_random
 
@@ -34,15 +31,19 @@ def gen_unique_id():
     return str(uuid4())
 
 
-def kwdict(kwargs):
-    """Make sure keyword arguments are not in unicode.
+if sys.version_info >= (3, 0):
+    def kwdict(kwargs):
+        return kwargs
+else:
+    def kwdict(kwargs):
+        """Make sure keyword arguments are not in unicode.
 
-    This should be fixed in newer Python versions,
-      see: http://bugs.python.org/issue4978.
+        This should be fixed in newer Python versions,
+        see: http://bugs.python.org/issue4978.
 
-    """
-    return dict((key.encode("utf-8"), value)
-                    for key, value in kwargs.items())
+        """
+        return dict((key.encode("utf-8"), value)
+                        for key, value in kwargs.items())
 
 
 def maybe_list(v):
@@ -53,13 +54,16 @@ def maybe_list(v):
     return [v]
 
 
-def repeatlast(it):
-    """Iterate over all elements in the iterator, and when its exhausted
-    yield the last value infinitely."""
-    for item in it:
-        yield item
-    while 1:    # pragma: no cover
-        yield item
+def fxrange(start=1.0, stop=None, step=1.0, repeatlast=False):
+    cur = start * 1.0
+    while 1:
+        if cur <= stop:
+            yield cur
+            cur += step
+        else:
+            if not repeatlast:
+                break
+            yield cur - step
 
 
 def retry_over_time(fun, catch, args=[], kwargs={}, errback=None,
@@ -88,11 +92,11 @@ def retry_over_time(fun, catch, args=[], kwargs={}, errback=None,
 
     """
     retries = 0
-    interval_range = xrange(interval_start,
-                            interval_max + interval_start,
-                            interval_step)
+    interval_range = fxrange(interval_start,
+                             interval_max + interval_start,
+                             interval_step, repeatlast=True)
 
-    for retries, interval in enumerate(repeatlast(interval_range)):
+    for retries, interval in enumerate(interval_range):
         try:
             return fun(*args, **kwargs)
         except catch, exc:
@@ -103,8 +107,14 @@ def retry_over_time(fun, catch, args=[], kwargs={}, errback=None,
             sleep(interval)
 
 
-def emergency_dump_state(state, open_file=open, dump=pickle.dump):
-    persist = tempfile.mktemp()
+def emergency_dump_state(state, open_file=open, dump=None):
+    from pprint import pformat
+    from tempfile import mktemp
+
+    if dump is None:
+        import pickle
+        dump = pickle.dump
+    persist = mktemp()
     say("EMERGENCY DUMP STATE TO FILE -> %s <-" % persist)
     fh = open_file(persist, "w")
     try:
@@ -165,3 +175,71 @@ def rpartition(S, sep):
         return S.rpartition(sep)
     else:  # Python <= 2.4:
         return _compat_rpartition(S, sep)
+
+
+class cached_property(object):
+    """Property descriptor that caches the return value
+    of the get function.
+
+    *Examples*
+
+    .. code-block:: python
+
+        @cached_property
+        def connection(self):
+            return Connection()
+
+        @connection.setter  # Prepares stored value
+        def connection(self, value):
+            if value is None:
+                raise TypeError("Connection must be a connection")
+            return value
+
+        @connection.deleter
+        def connection(self, value):
+            # Additional action to do at del(self.attr)
+            if value is not None:
+                print("Connection %r deleted" % (value, ))
+
+    """
+
+    def __init__(self, fget=None, fset=None, fdel=None, doc=None):
+        self.__get = fget
+        self.__set = fset
+        self.__del = fdel
+        self.__doc__ = doc or fget.__doc__
+        self.__name__ = fget.__name__
+        self.__module__ = fget.__module__
+
+    def __get__(self, obj, type=None):
+        if obj is None:
+            return self
+        try:
+            return obj.__dict__[self.__name__]
+        except KeyError:
+            value = obj.__dict__[self.__name__] = self.__get(obj)
+            return value
+
+    def __set__(self, obj, value):
+        if obj is None:
+            return self
+        if self.__set is not None:
+            value = self.__set(obj, value)
+        obj.__dict__[self.__name__] = value
+
+    def __delete__(self, obj):
+        if obj is None:
+            return self
+        try:
+            value = obj.__dict__.pop(self.__name__)
+        except KeyError:
+            pass
+        else:
+            if self.__del is not None:
+                self.__del(obj, value)
+
+    def setter(self, fset):
+        return self.__class__(self.__get, fset, self.__del)
+
+    def deleter(self, fdel):
+        return self.__class__(self.__get, self.__set, fdel)
