@@ -1,3 +1,5 @@
+import sys
+
 ############## __builtin__.all ##############################################
 
 try:
@@ -38,7 +40,7 @@ class _Link(object):
     __slots__ = 'prev', 'next', 'key', '__weakref__'
 
 
-class OrderedDict(dict, MutableMapping):
+class CompatOrderedDict(dict, MutableMapping):
     """Dictionary that remembers insertion order"""
     # An inherited dict maps keys to values.
     # The inherited dict provides __getitem__, __len__, __contains__, and get.
@@ -198,7 +200,13 @@ class OrderedDict(dict, MutableMapping):
         """
         if not self:
             raise KeyError('dictionary is empty')
-        key = (last and reversed(self) or iter(self)).next()
+        if last:
+            if sys.platform.startswith("java"):
+                key = self.keys()[-1]
+            else:
+                key = reversed(self).next()
+        else:
+            key = iter(self).next()
         value = self.pop(key)
         return key, value
 
@@ -232,3 +240,8 @@ class OrderedDict(dict, MutableMapping):
 
     def __ne__(self, other):
         return not (self == other)
+
+try:
+    from collections import OrderedDict
+except ImportError:
+    OrderedDict = CompatOrderedDict
